"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useDelayState;
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _rcUtil = require("rc-util");
var _react = _interopRequireDefault(require("react"));
// We need wait for outside state updated.
// Which means need 2 effect:
// 1. Outside sync state
// 2. Still may be old state
// 3. Safe to sync state
var DELAY_TIMES = 2;

/**
 * Will be `true` immediately for next effect.
 * But will be `false` for a delay of effect.
 */
function useDelayState(value, defaultValue, onChange) {
  var _useMergedState = (0, _rcUtil.useMergedState)(defaultValue, {
      value: value
    }),
    _useMergedState2 = (0, _slicedToArray2.default)(_useMergedState, 2),
    state = _useMergedState2[0],
    setState = _useMergedState2[1];
  var _React$useState = _react.default.useState(false),
    _React$useState2 = (0, _slicedToArray2.default)(_React$useState, 2),
    times = _React$useState2[0],
    setTimes = _React$useState2[1];
  var nextValueRef = _react.default.useRef(value);

  // ============================= Update =============================
  var doUpdate = (0, _rcUtil.useEvent)(function () {
    setState(nextValueRef.current);
    if (onChange && state !== nextValueRef.current) {
      onChange(nextValueRef.current);
    }
  });
  var updateValue = (0, _rcUtil.useEvent)(function (next, immediately) {
    nextValueRef.current = next;
    if (next || immediately) {
      doUpdate();
      setTimes(false);
    } else {
      setTimes(0);
    }
  });

  // ============================= Effect =============================
  _react.default.useEffect(function () {
    if (times === DELAY_TIMES) {
      doUpdate();
    } else if (times !== false && times < DELAY_TIMES) {
      setTimes(times + 1);
    }
  }, [times, doUpdate]);
  return [state, updateValue];
}